;-----------------------------------------------------------------------
; Sample AutoHotkey script for using a coin or bill acceptor with
; the photobooth. The script looks for when the booth switches from
; the processing.jpg screen to the ready.jpg screen and then sends F6
; to switch the photobooth to standby mode (with the welcome.jpg screen
; displayed). When the coin/bill acceptor detects the correct money it
; should send the key F12 to exit standby mode.
; 
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script works with:
; DSLR Remote Pro for Windows v1.9.1 or later
; NKRemote v1.4 or later
; PSRemote v1.9 or later
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;-----------------------------------------------------------------------
#SingleInstance force

; Set TimeoutInSecs to the number of seconds before the booth times out
; and returns to welcome screen. Set this to 0 to disable the timeout
TimeoutInSecs = 120

; loop forever monitoring the status of the photobooth screen by looking
; at the window title which is in the form:
; Breeze Systems Photobooth - <screen_pathname>
LookForReady = 1
Timeout = 0
Loop
{
	IfWinExist, Breeze Systems Photobooth
	{
		WinGetTitle, Title, Breeze Systems Photobooth
		if Title contains ready.jpg
		{
			; Photobooth is displaying ready screen - are we looking for ready.jpg?
			if LookForReady
			{
				; yes, photobooth has just switched from processing.jpg to ready.jpg
				LookForReady = 0
				WinActivate, Breeze Systems Photobooth
				; Send F6 to switch to standby
				Send {F6}
				Timeout = 0
			}
			if (Timeout > 0 and A_TickCount > Timeout)
			{
				WinActivate, Breeze Systems Photobooth
				; Send F6 to switch to standby
				Send {F6}
				Timeout = 0
			}
		}
		else if Title contains processing.jpg
		{
			; Photobooth is displaying ready screen - start looking for ready.jpg
			LookForReady = 1
		}
	}
	else
	{
		LookForReady = 1
	}
	Sleep 100	; sleep for 1/10th sec to avoid hogging the processor
}
Return

; Exit standby mode when F12 is pressed
F12::
IfWinExist, Breeze Systems Photobooth
{
	WinGetTitle, Title, Breeze Systems Photobooth
	if Title contains welcome.jpg
	{
		if (TimeoutInSecs > 0)
		{
			Timeout := A_TickCount + TimeoutInSecs * 1000
		}
		WinActivate, Breeze Systems Photobooth
		Send {F6}
	}
}
return
